@@ -15,6 +15,7 @@ def echo_info(msg):
     """colored cli feedback"""
     click.echo(click.style(msg, fg="cyan"))
 
+
 def replace_vars(string: str, vars: typing.Optional[typing.Dict[str, str]] = None) -> str:
     """Replaces $(placeholders) in a string by values from a dict until no more values are being replaced.
 
@@ -23,6 +24,9 @@ def replace_vars(string: str, vars: typing.Optional[typing.Dict[str, str]] = Non
     - day: Current date's day
     - month: Current date's month
     - year: Current date's year
+    - hour: Current date's hour
+    - minute: Current date's minute
+    - second: Current date's second
     """
     # set some defaults
     if vars is None:
